<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}{% endblock %} - Alarme</title>
    <link rel="stylesheet" type="text/css" href="{{ app.router.static.url(filename='css/bootstrap.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ app.router.static.url(filename='css/style.css') }}">
</head>
<body>
{% block content %}{% endblock %}
</body>
</html>