body {
    background: #ebe6cc;
}
.logo {
    width: 100%;
    max-width: 340px;
    cursor: pointer;
}
.container-fluid {
    max-width: 400px;
    text-align: center;
    padding-right: 8px;
    padding-left: 8px;
}
.current-state {
    margin: 4px 6px 12px 6px;
    text-align: center;
}
.current-state-value {
    text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2);
    width: 100%;
}
.behaviour-form {
    display: inline-block;
}
.behaviour {
    color: white;
    border-radius: 4px;
    text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2);
    background: rgb(150, 150, 150);
    outline: none;
    margin: 4px;
    cursor: pointer;
}
.behaviour:hover, .current-state-value:hover {
    filter: brightness(85%);
}
